
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.23.17',
    'branch_nick': 'release-1.23-LTS',
    'revision_id': '4579a8a5bd264cd254f48e2748527c071859cc74',
    'revno': 10115
}
